@@ -16,5 +16,8 @@
 
 # -*- mode: python; mode: font-lock -*-
 
+from __future__ import unicode_literals
+from __future__ import print_function
+
 __import__('pkg_resources').declare_namespace(__name__)
 
